A variável \_\_TOAD\_\_
=======================

Uma das nossas regras é **"Não misture HTML com JavaScript"**, e com isso queremos dizer que você não deve incluir nenhum código [JavaScript][JAVASCRIPT] nas páginas [HTML][HTML]. Porém tudo deve ser _dosado_, e por isso abrimos uma exceção.

Toda aplicação _jQuery TOAD_ requer que antes de chamar a biblioteca `jquery-toad.js` em si, precisa-se definir qual será o nome do módulo principal, onde estarão aninhados todos os outros módulos, e isso é feito definindo uma variável global chamada **`__TOAD__`**.

```html
<script>
    var __TOAD__ = "MYAPP"
</script>
```
O nome que for definido aqui ditará como serão construídos os demais scripts, pois tudo será acessado à partir dessa variável global. Isso também corrobora com nosso outro objetivo, **"Modularize"**, visto que se trata de um módulo principal.

Ex:

```js
MYAPP.namespace(/*...*/)
```

Tanto os objetos da própria biblioteca _jQuery TOAD_ quanto os objetos da aplicação que está sendo desenvolvida serão acessados à partir desse módulo inicial.

Durante um tempo consideramos disponibilizar uma variável global, tipo **`$toad`**, assim como a própria [jQuery][JQUERY] faz com o uso de **`$`**, [AngularJS][ANGULARJS] faz com **`angular`**, ou [Vue][VUEJS] faz com **`Vue`**.

> PS: Aqui não estamos falando de [UMD][UMD], [AMD][AMD], [CommonJS][CommonJS] & Cia. Depois falamos disso.

Pensamos em até usar algo como **`App`** ou **`$App`**, e até **`ClientApp`**, porque consideramos que se por um lado teríamos o módulo da própria **jQuery TOAD** a aplicação em si também poderia ter o seu próprio espaço de nomes.

Por fim, entendemos que o nome da aplicação tem muito significado quando estamos lendo o código, e como a nossa proposta é de simplesmente auxiliar no desenvolvimento da sua aplicação, preferimos ficar como coadjuvante. Então deixamos você dizer que nome prefere para sua aplicação, e então preparamos o mínimo necessário de utilitários que você precisará e o resto é contigo.

Como resultado, nós temos uma forma bem simples pra desenvolver nossa aplicação, visto que o ponto central já está definido.

**Um exemplo:** Caso você queira acessar um utilitário que a própria _jQuery TOAD_ disponibiliza como a função `setPageTitle` (que define o título da página) ou um outro utilitário que você mesmo definiu, você fará isso da mesma forma:

```js
var utils = MYAPP.import('utils');

utils.setPageTitle('');
utils.myMethod();
```

Isso é bom porque o foco é sua aplicação, então deixamos tudo em volta dela. Você só precisa saber que sem definir essa variável a _jQuery TOAD_ se recusará a continuar.

Você pode definir qualquer string válida para o nome de sua aplicação, mas recomendamos um nome curto e significativo, como o nome de sua aplicação ou sigla dela, e apesar de não fazer diferença, sugerimos usar tudo em maiúsculo (só pra esse nome). É só uma sugestão porque achamos bonito, mas você é quem manda.

<!-- Links -->
[JQUERY]: https://jquery.com "jQuery"
[TOAD]: https://github.com/e5r/jquery-toad "jQuery TOAD"
[JAVASCRIPT]: https://developer.mozilla.org/pt-BR/docs/Web/JavaScript
[HTML]: https://developer.mozilla.org/pt-BR/docs/Web/HTML
[UMD]: https://github.com/umdjs/umd
[AMD]: https://github.com/amdjs/amdjs-api/wiki/AMD
[CommonJS]: http://wiki.commonjs.org/wiki/CommonJS
[ANGULARJS]: https://angularjs.org
[VUEJS]: https://vuejs.org
